#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hledger
version:              1.52.1
visibility:           public
id:                   hledger-1.52.1-5VGOYYO9jeoH3ogKE2nvVO
key:                  hledger-1.52.1-5VGOYYO9jeoH3ogKE2nvVO
license:              GPL-3.0-or-later
maintainer:           Simon Michael <simon@joyful.com>
author:               Simon Michael <simon@joyful.com>
stability:            stable
homepage:             http://hledger.org
synopsis:             Command-line interface for the hledger accounting system
description:
    The command-line interface for the hledger accounting system.
    Its basic function is to read a plain text file describing
    financial transactions and produce useful reports.

    hledger is a robust, cross-platform set of tools for tracking money,
    time, or any other commodity, using double-entry accounting and a
    simple, editable file format, with command-line, terminal and web
    interfaces. It is a Haskell rewrite of Ledger, and one of the leading
    implementations of Plain Text Accounting. Read more at:
    <https://hledger.org>

category:             Finance, Console
abi:                  37b4c8820d16085b6116b16a4cca51d0
exposed:              True
exposed-modules:
    Hledger.Cli Hledger.Cli.Anchor Hledger.Cli.Anon
    Hledger.Cli.CliOptions Hledger.Cli.Commands
    Hledger.Cli.Commands.Accounts Hledger.Cli.Commands.Activity
    Hledger.Cli.Commands.Add Hledger.Cli.Commands.Aregister
    Hledger.Cli.Commands.Balance Hledger.Cli.Commands.Balancesheet
    Hledger.Cli.Commands.Balancesheetequity
    Hledger.Cli.Commands.Cashflow Hledger.Cli.Commands.Check
    Hledger.Cli.Commands.Close Hledger.Cli.Commands.Codes
    Hledger.Cli.Commands.Commodities Hledger.Cli.Commands.Demo
    Hledger.Cli.Commands.Descriptions Hledger.Cli.Commands.Diff
    Hledger.Cli.Commands.Files Hledger.Cli.Commands.Help
    Hledger.Cli.Commands.Import Hledger.Cli.Commands.Incomestatement
    Hledger.Cli.Commands.Notes Hledger.Cli.Commands.Payees
    Hledger.Cli.Commands.Prices Hledger.Cli.Commands.Print
    Hledger.Cli.Commands.Register Hledger.Cli.Commands.Rewrite
    Hledger.Cli.Commands.Roi Hledger.Cli.Commands.Run
    Hledger.Cli.Commands.Setup Hledger.Cli.Commands.Stats
    Hledger.Cli.Commands.Tags Hledger.Cli.CompoundBalanceCommand
    Hledger.Cli.Conf Hledger.Cli.DocFiles Hledger.Cli.Script
    Hledger.Cli.Utils Hledger.Cli.Version

hidden-modules:       Paths_hledger
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hledger-1.52.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/hledger
hs-libraries:         HShledger-1.52.1-5VGOYYO9jeoH3ogKE2nvVO
depends:
    Decimal-0.5.2-KxiTI8QDDOfKWBpfbTZT7a
    Diff-1.0-4F96IMAnGh7AOlcbsBnTkK
    aeson-2.2.2.0-Fs8lpfl0CTvIUZfvQfMaj3
    ansi-terminal-1.1-5MUD2jLYLiA9e4scB8VtNm base-4.18.2.1
    bytestring-0.11.5.3 cmdargs-0.10.22-E2EkQI5shziHkHOdPiVHiM
    containers-0.6.7 data-default-0.7.1.3-77Hl1aAsEdQ8CHtlu2eaQ1
    directory-1.3.8.5 extra-1.7.16-HALhSAGzjFKFE31SaPlKoT
    filepath-1.4.300.1 githash-0.1.7.0-1wNkPw9Ij1g8wKH8RjgIZs
    hashable-1.4.7.0-7UbNEk44IiMJoszryX1sDf haskeline-0.8.2.1
    hledger-lib-1.52.1-6bFhK0PJJSHEO4VH5hmrb5
    http-client-0.7.19-DALlHG22JR86LK61BczJck
    http-types-0.12.4-LNdcYYtCiEAAA2abLyIqKh
    lucid-2.11.20260427-QvLA0HJrEcJpl3sxiKEnl
    math-functions-0.3.4.4-EpoOzVotTrlElJ7eEMGyWg
    megaparsec-9.7.1-GpPguTGROHLFp8M4r84ARz
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    modern-uri-0.3.6.1-7XRy8DgvtgRFlnOsFYbt20 mtl-2.3.1
    process-1.6.19.0 regex-tdfa-1.3.2.5-3SUtr6zl8m4ZpuEbYfBOR
    req-3.13.4-9nflDCIVG58719WTdJ3Bca
    safe-0.3.21-DjuyYkeoSg19eA55FDakyc
    shakespeare-2.1.7.1-6AIpAh5ygZ2BANHupYzTFU
    split-0.2.5-IWqDtjl2GAk74sJK8n7xVw
    tabular-0.2.2.8-Ly9fepE9sHFB2l1Bgv9bkV
    tasty-1.5.3-AzHeewJiLP68tKN5TZJG9J
    temporary-1.3-5Wz97ntF8DMBd6stUm3CX7 text-2.0.2
    text-ansi-0.3.0.1-Iog0YbjvKtsAYMcq05fxJq time-1.12.2
    timeit-2.0-DwmItJuhuSm6aktMh1S1ZM transformers-0.6.1.0
    unordered-containers-0.2.21-DZIhPqSL0N2YNV8fYQEJ8
    utf8-string-1.0.2-2At7L47Qsbs4rlGLlJEQb1
    utility-ht-0.0.17.2-CDUkvx1zbHgHc8LQQSuYhg
    wizards-1.0.3-EMndOhiYuHdGTEqrX5mo0v

haddock-interfaces:   /usr/share/doc/hledger/html/hledger.haddock
haddock-html:         /usr/share/doc/hledger/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

